@@ -14,9 +14,9 @@
    General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
-   USA. */
+   along with this program; if not, a copy is available at
+   http://www.r-project.org/Licenses/
+*/
 
 #include <stdarg.h>
 #include <stdio.h>
