@@ -14,9 +14,9 @@
    General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
-   USA. */
+   along with this program; if not, a copy is available at
+   http://www.r-project.org/Licenses/
+*/
 
 #include <stdlib.h>
 #include <ctype.h>
@@ -522,11 +522,18 @@ read_machine_int32_info (struct file_handle * h, int size, int count)
 	   data[6] == 1 ? "big-endian" : (data[6] == 2 ? "little-endian"
 					  : "unknown")));
 
+/* Removes a problem with SPSS 15 files, according to
+http://www.nabble.com/problem-loading-SPSS-15.0-save-files-t2726500.html
+We just deal with the cases we know are wrong (2 and 3 are OK).
+*/
   /* PORTME: Character representation code. */
-  if (data[7] != 2 && data[7] != 3)
+  if (data[7] == 1 || data[7] == 4)
     lose ((_("%s: File-indicated character representation code (%s) is not ASCII"), h->fn,
        data[7] == 1 ? "EBCDIC" : (data[7] == 4 ? "DEC Kanji" : "Unknown")));
-
+  if(data[7] >= 500)
+      warning(_("%s: File-indicated character representation code (%d) looks like a Windows codepage"), h-> fn, data[7]);
+  else if(data[7] > 4)
+      warning(_("%s: File-indicated character representation code (%d) is unknown"), h-> fn, data[7]);
   return 1;
 
 lossage:
@@ -1463,9 +1470,6 @@ read_compressed_data (struct file_handle * h, R_flt64 * temp)
       p = ext->x;
     }
 
-  /* Not reached. */
-  if (!(0)) error("assert failed : 0");
-
 winnage:
   /* We have filled up an entire record.  Update state and return
      successfully. */
